@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # generate python wrappers from the XML API description
 #
@@ -430,6 +430,9 @@ skip_impl = (
     'virNetworkGetUUID',
     'virNetworkGetUUIDString',
     'virNetworkLookupByUUID',
+    'virNetworkPortGetUUID',
+    'virNetworkPortGetUUIDString',
+    'virNetworkPortLookupByUUID',
     'virDomainGetAutostart',
     'virNetworkGetAutostart',
     'virDomainBlockStats',
